@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: keymap.c,v 1.10 2003/01/03 01:05:05 nalin Exp $"
+#ident "$Id: keymap.c,v 1.11 2003/01/14 03:04:30 nalin Exp $"
 #include "../config.h"
 #include <stdlib.h>
 #include <stdio.h>
@@ -966,12 +966,8 @@ _vte_keymap_map(guint keyval,
 		return;
 	}
 
-	/* Build mode masks.  Numlock negates application cursor mode. */
-	if (modifiers & VTE_NUMLOCK_MASK) {
-		cursor_mode = cursor_default;
-	} else {
-		cursor_mode = app_cursor_keys ? cursor_app : cursor_default;
-	}
+	/* Build mode masks. */
+	cursor_mode = app_cursor_keys ? cursor_app : cursor_default;
 	keypad_mode = app_keypad_keys ? keypad_app : keypad_default;
 	if (sun_mode) {
 		fkey_mode = fkey_sun;
