@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: nativeecho.c,v 1.1 2002/12/03 03:49:59 nalin Exp $"
+#ident "$Id: nativeecho.c,v 1.2 2003/01/14 03:04:30 nalin Exp $"
 #include "../config.h"
 #include <limits.h>
 #include <stdio.h>
@@ -38,10 +38,6 @@ main(int argc, char **argv)
 		return 1;
 	}
 
-	if (isatty(STDOUT_FILENO)) {
-		printf(ESC "%%@");
-	}
-
 	for (i = 1; i < argc; i++) {
 		l = strtol(argv[i], &p, 0);
 		while (l > 0) {
